==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/text/l10n/af.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "text document" : "teksdokument",
    "Readme" : "Leesmy",
    "Text" : "Teks",
    "📝 Collaborative document editing" : "📝 Samewerkende dokumentredigering",
    "Use current version" : "Gebruik huidige weergawe",
    "Use the saved version" : "Gebruik die bewaarde weergawe",
    "Reconnect" : "Herverbind",
    "Guest" : "Gas",
    "guest" : "gas",
    "Show author colors" : "Toon outeurkleure",
    "Author colors are only shown until everyone has closed the document." : "Outeurkleure word slegs getoon tot almal die dokument toegemaak het.",
    "Saving …" : "Bewaar tans…",
    "Saved" : "Bewaar",
    "Last saved {lastSaved}" : "Laas bewaar {lastSaved}",
    "Unsaved changes" : "Onbewaarde veranderinge",
    "Keyboard shortcuts" : "Sneltoetse",
    "Bold" : "Vet",
    "Italic" : "Skuins",
    "Strikethrough" : "Deurstreep",
    "Heading 1" : "Kop 1",
    "Heading 6" : "Kop 6",
    "Unordered list" : "Ongesorteerde lys",
    "Ordered list" : "Gesorteerde lys",
    "Blockquote" : "Blokaanhaling",
    "Unsupported image type" : "Onondersteunde beeldtipe",
    "Headings" : "Koppe",
    "Heading 2" : "Kop 2",
    "Heading 3" : "Kop 3",
    "Heading 4" : "Kop 4",
    "Heading 5" : "Kop 5",
    "Info" : "Inligting",
    "Success" : "Sukses",
    "Warning" : "Waarskuwing",
    "Edit" : "Wysig",
    "New text document" : "Nuwe teksdokument",
    "Enter your name so other users can see who is editing" : "Voer u naam in sodat andere kan weet wie hieraan werk",
    "Insert image" : "Voer beeld in",
    "Insert an image" : "Voer ’n beeld in",
    "Link file" : "Koppel lêer",
    "Select file to link to" : "Kies lêer om na te koppel",
    "Currently active users:" : "Gebruikers wat tans aktief is:",
    "ToDo list" : "Moet-doen-lys"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.7.tar.bz2: nextcloud/apps/text/l10n/af.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "text document" : "teksdokument",
    "File not found" : "Lêer nie gevind nie",
    "Readme" : "Leesmy",
    "Text" : "Teks",
    "📝 Collaborative document editing" : "📝 Samewerkende dokumentredigering",
    "Use current version" : "Gebruik huidige weergawe",
    "Use the saved version" : "Gebruik die bewaarde weergawe",
    "Reconnect" : "Herverbind",
    "Guest" : "Gas",
    "guest" : "gas",
    "Offline" : "Vanlyn",
    "Saving …" : "Bewaar tans…",
    "Saved" : "Bewaar",
    "Unsaved changes" : "Onbewaarde veranderinge",
    "Keyboard shortcuts" : "Sneltoetse",
    "Bold" : "Vet",
    "Italic" : "Skuins",
    "Strikethrough" : "Deurstreep",
    "Heading 1" : "Kop 1",
    "Heading 6" : "Kop 6",
    "Unordered list" : "Ongesorteerde lys",
    "Ordered list" : "Gesorteerde lys",
    "Blockquote" : "Blokaanhaling",
    "to" : "aan",
    "Edit" : "Wysig",
    "Headings" : "Koppe",
    "Heading 2" : "Kop 2",
    "Heading 3" : "Kop 3",
    "Heading 4" : "Kop 4",
    "Heading 5" : "Kop 5",
    "Info" : "Inligting",
    "Success" : "Sukses",
    "Warning" : "Waarskuwing",
    "Details" : "Besonderhede",
    "Show author colors" : "Toon outeurkleure",
    "Author colors are only shown until everyone has closed the document." : "Outeurkleure word slegs getoon tot almal die dokument toegemaak het."
},
"nplurals=2; plural=(n != 1);");
